@@ -20,7 +20,6 @@
 # limitations under the License.
 
 from __future__ import print_function
-import base64
 
 from opsramp.base import ApiWrapper
 
@@ -60,19 +59,6 @@ class Script(ApiWrapper):
     def __init__(self, parent, uuid):
         super(Script, self).__init__(parent.api, 'scripts/%s' % uuid)
 
-    def get(self):
-        return self.api.get()
-
-    # Returns a string containing a base64 encoded version of the
-    # content of the specified file. It was quite finicky to come
-    # up with a method that works on both Python 2 and 3 so please
-    # don't modify this, or test carefully if you do.
-    @staticmethod
-    def encode_payload(fname):
-        with open(fname, 'rb') as f:
-            content = base64.b64encode(f.read())
-        return content.decode()
-
     # A helper function for use with mkparameter & mkscript.
     @staticmethod
     def mkattachment(name, payload):
